RetryHandle

Struct RetryHandle 

pub struct RetryHandle<Inj, Dur> { /* private fields */ }
Persistent retry handle

Implementations

Source

impl<'a, Inj, Dur> RetryHandle<Inj, Dur>
where Inj: RetryInjector<'a>, Dur: IntoIterator<Item = Duration> + Clone,

pub fn new(injector: Inj, durations: Dur) -> Self

Create a new persistent retry handle from an injector and a cloneable delay iterator

pub async fn retry_pending<F>( &mut self, concurrency_limit: usize, operation: &dyn Fn(Inj::Input) -> F, )
where F: Future<Output = Inj::Res>,

Start concurrent persistent retry of pending input loaded from the injector using the given operation and concurrency limit

pub async fn retry_stream<F, S>( &mut self, stream: S, concurrency_limit: usize, operation: &dyn Fn(Inj::Input) -> F, )
where F: Future<Output = Inj::Res>, S: Stream<Item = (Inj::Id, Inj::Input)>,

Start concurrent persistent retry of input loaded from the given stream using the given operation and concurrency limit

pub async fn retry<F>( &mut self, id: Inj::Id, input: Inj::Input, operation: &dyn Fn(Inj::Input) -> F, )
where F: Future<Output = Inj::Res>,

Persistently retry a given input (uniquely identified by the given id) using the given operation