pub struct RetryConfig {
pub count: usize,
pub min_backoff: u64,
pub max_backoff: u64,
}Expand description
A serializable retry configuration for a random range and finite retry count
Fields
count: usizehow many times will we retry the operation
min_backoff: u64the minimum amount of milliseconds to wait before retrying
max_backoff: u64the maximum amount of milliseconds to wait before retrying