pub struct RetryHandle<Inj, Dur> { /* private fields */ }Expand description
Persistent retry handle
Implementations
Sourceimpl<'a, Inj, Dur> RetryHandle<Inj, Dur>
impl<'a, Inj, Dur> RetryHandle<Inj, Dur>
Sourcepub fn new(injector: Inj, durations: Dur) -> Self
pub fn new(injector: Inj, durations: Dur) -> Self
Create a new persistent retry handle from an injector and a cloneable delay iterator
Sourcepub async fn retry_pending<F>(
&mut self,
concurrency_limit: usize,
operation: &dyn Fn(Inj::Input) -> F,
)
pub async fn retry_pending<F>( &mut self, concurrency_limit: usize, operation: &dyn Fn(Inj::Input) -> F, )
Start concurrent persistent retry of pending input loaded from the injector using the given operation and concurrency limit
Sourcepub async fn retry_stream<F, S>(
&mut self,
stream: S,
concurrency_limit: usize,
operation: &dyn Fn(Inj::Input) -> F,
)
pub async fn retry_stream<F, S>( &mut self, stream: S, concurrency_limit: usize, operation: &dyn Fn(Inj::Input) -> F, )
Start concurrent persistent retry of input loaded from the given stream using the given operation and concurrency limit